// BrowserAssistInterop.cs  v1.0.0
// This file contains classes that can be used to integrate with the BrowserAssist plugin by JayJayWon. The main class 'BAInterop' has a range of static methods and properties that can be used once a reference to Browser Assist has been established.This reference can be set using the static property 'BAPlugin'.Other static classes are included that provide unique enumerations for various parameters that can be passed to BrowserAssist.
// To use this file you will need to change the namespace to to one that matches the namespace used by a plugin wanting to interact with BrowserAssist. This file will also need to be referenced in the VAM cslist file along with any other .cs files. NO OTHER CHANGES SHOULD BE REQUIRED TO THIS FILE

using SimpleJSON;
using System;
using System.Collections.Generic;

namespace JayJayWon
{
    public class BAOrderedResourceFilter : BAResourceFilter
    {
        public int resourceOrder { get; set; } = BAResultsSortModeEnum.AtoZ;
        public BAOrderedResourceFilter(int resourceType) : base(resourceType)
        {

        }

        public override JSONClass GetJSON()
        {
            var jc = base.GetJSON();
            jc["resourceOrder"].AsInt = resourceOrder;

            return jc;
        }

        public override void RestoreJSON(JSONClass jc)
        {
            base.RestoreJSON(jc);
            if (jc["resourceOrder"] != null) resourceOrder = jc["resourceOrder"].AsInt;
        }
    }

    public class BAResourceFilter : BACreatorFilter
    {
        // 'creatorType' must always be set to one of the integer enumerations in 'BACreatorType'. If set to 'BACreatorType.userDefault' then the filter will be set to the BrowserAssist default value.
        public int creatorType { get; set; } = BACreatorTypeEnum.allLocalAndCreators;

        // 'creatorName' only needs to be set if creatorType is set to 'BACreatorType.specificCreator'. When set, must be one of the strings returned by BAInterop.GetCreatorNames()
        public string creatorName { get; set; } = "";

        // 'localFolder' only needs to be set if creatorType is set to 'BACreatorType.localFolders'. When set, should be a folder within the VAM storage location for that resource type. If set to "", then then the root folder for that resource type will be used.
        public string localFolder { get; set; } = "";

        // 'localFolder' only needs to be set if creatorType is set to 'BACreatorType.localFolders'. When set, will indicate if resources with in sub folders of the local folder are included.
        public bool includeSubFolders { get; set; } = false;

        // 'varLicenseType' only needs to be set if creatorType is set to 'BACreatorType.allPackageCreators' or 'BACreatorType.specificCreator'. When set, should be one of the integer enumerations in 'BALicenseType'.
        public int varLicenseType { get; set; } = BALicenseTypeEnum.Any;

        // 'resourceNameFilterMode' will determine what filter search logic is applied when filtering by the 'resourceName' field.
        public int resourceNameFilterMode { get; set; } = BAResourceNameFilterModeEnum.userDefault;

        // 'resourceName' will filter resources that have names which dont match the specified string. The comparison logic is determined by the 'resourceNameFilterMode'. If 'resourceName' is set to an empty string (e.g. resourceName =""), then no resources will be filtered based on the resource's name.
        public string resourceName { get; set; } = "";

        public BAResourceFilter(int resourceType) : base(resourceType)
        {

        }

        public override JSONClass GetJSON()
        {
            var jc = base.GetJSON();
            jc["creatorType"].AsInt = creatorType;
            jc["creatorName"] = creatorName;
            jc["localFolder"] = localFolder;
            jc["includeSubFolders"].AsBool = includeSubFolders;
            jc["varLicenseType"].AsInt = varLicenseType;
            jc["resourceNameFilterMode"].AsInt = resourceNameFilterMode;
            jc["resourceName"] = resourceName;

            return jc;
        }

        public override void RestoreJSON(JSONClass jc)
        {
            base.RestoreJSON(jc);
            if (jc["creatorType"] != null) creatorType = jc["creatorType"].AsInt;
            if (jc["creatorName"] != null) creatorName = jc["creatorName"];
            if (jc["localFolder"] != null) localFolder = jc["localFolder"];
            if (jc["includeSubFolders"] != null) includeSubFolders = jc["includeSubFolders"].AsBool;
            if (jc["varLicenseType"] != null) varLicenseType = jc["varLicenseType"].AsInt;
            if (jc["resourceNameFilterMode"] != null) resourceNameFilterMode = jc["resourceNameFilterMode"].AsInt;
            if (jc["resourceName"] != null) resourceName = jc["resourceName"];
        }
    }

    public class BACreatorFilter
    {
        // 'resourceType' must always be set to one of the integer enumerations in 'BAResourceType'
        public int resourceType { get; protected set; } = BAResourceTypeEnum.scene;

        // 'tagGroupType' must always be set to one of the integer enumerations in 'BATagGroupType'. If set to 'BATagGroupType.userDefault' then the filter will be set to the BrowserAssist default value.
        public int tagGroupType { get; set; } = BATagGroupTypeEnum.anyTags;

        // 'userTagName' only needs to be set if tagGroupType is set to 'BATagGroupType.userTag'. When set, must be one of the strings returned by BAInterop.GetTagNames()
        public string userTagName { get; set; } = "";

        // 'showHidden' must always be set to one of the integer enumerations in 'BAShowHidden'. If set to 'BAShowHidden.userDefault' then the filter will be set to the BrowserAssist default value.
        public int showHidden { get; set; } = BAShowHiddenEnum.excludeHidden;

        // 'onlyFav' must always be set to one of the integer enumerations in 'BAOnlyFavorite'. If set to 'BAOnlyFavorite.userDefault' then the filter will be set to the BrowserAssist default value.
        public int onlyFav { get; set; } = BAOnlyFavoriteEnum.includeNotFavorites;

        // 'onlyNew' must always be set to one of the integer enumerations in 'BAOnlyNew'. If set to 'BAOnlyNew.userDefault' then the filter will be set to the BrowserAssist default value.
        public int onlyNew { get; set; } = BAOnlyNewEnum.includeNotNew;
        public BACreatorFilter(int resourceType)
        {
            this.resourceType = resourceType;
        }

        public virtual JSONClass GetJSON()
        {
            var jc = new JSONClass();
            jc["resourceType"].AsInt = resourceType;
            jc["tagGroupType"].AsInt = tagGroupType;
            jc["userTagName"] = userTagName;
            jc["showHidden"].AsInt = showHidden;
            jc["onlyFav"].AsInt = onlyFav;
            jc["onlyNew"].AsInt = onlyNew;

            return jc;
        }

        public virtual void RestoreJSON(JSONClass jc)
        {
            if (jc["resourceType"] !=null) resourceType = jc["resourceType"].AsInt;
            if (jc["tagGroupType"] != null) tagGroupType = jc["tagGroupType"].AsInt;
            if (jc["userTagName"] != null) userTagName = jc["userTagName"];
            if (jc["showHidden"] != null) showHidden = jc["showHidden"].AsInt;
            if (jc["onlyFav"] != null) onlyFav = jc["onlyFav"].AsInt;
            if (jc["onlyNew"] != null) onlyNew = jc["onlyNew"].AsInt;
        }
    }

    public class BAInterop
    {
        private static MVRScript _BAPlugin;
        public static bool enableFailureLogging { get; set; } = false;

        // 'BAInteropVersion' will return the version of the interop specification used by the currently connected BrowserAssist plugin. If no BrowserAssist plugin is connected the property will be set to -1.
        public static int BAInteropVersion { get; private set; } = -1;

        // 'BAPlugin' must be set to reference the BrowserAssist plugin to be connected to.
        public static MVRScript BAPlugin
        {
            get
            {
                return _BAPlugin;
            }
            set
            {
                if (value == null)
                {
                    _BAPlugin = null;
                    BAInteropVersion = -1;
                }
                else
                {
                    _BAPlugin = value;
                    var jc = _BAPlugin.GetJSON();
                    if (jc["BAInteropVersion"] != null) BAInteropVersion = jc["BAInteropVersion"].AsInt;
                    else
                    {
                        BAInteropVersion = -1;
                        if (enableFailureLogging) SuperController.LogMessage("BAInterop.BAPlugin: The specidied MVRScript is not a plugin version that supports  BrowserAssist integration.");
                    }
                }

            }
        }

        // 'isBAenabled' will return true if a connection is established with BrowserAssist and that plugin is not currently disabled.
        public static bool isBAenabled
        {
            get
            {
                return BAPlugin != null && BAPlugin.enabled;
            }
        }


        public delegate void CallbackFail(string failureMessage, int resourceTypeEnum);
        public delegate void CallbackException(string exceptionMessage, int resourceTypeEnum);

        public delegate void GetTagNamesCallback(List<string> tagNamesList, int resourceTypeEnum);

        // 'GetTagNames' will obtain a list of all Tag Names for the specified Resource Type. The callback method specified will be triggered with the list of tag names as a parameter. Alternative callbacks can optionally be specified if the function fails or triggers an exception
        public static void GetTagNames(int resourceTypeEnum, GetTagNamesCallback callback, CallbackFail callbackFail = null, CallbackException callbackException = null)
        {
            try
            {
                if (isBAenabled)
                {
                    var tagsList = new List<string>();

                    JSONStorableAction callbackActionSuccess = new JSONStorableAction("successCallback", delegate
                    {
                        if (callback != null) callback(tagsList, resourceTypeEnum);
                    });

                    JSONStorableString callbackActionFail = new JSONStorableString("failCallback", "", delegate (string failureMessage)
                    {
                        if (enableFailureLogging) SuperController.LogMessage("BAInterop.GetTagNames: " + failureMessage);
                        if (callbackFail != null) callbackFail(failureMessage, resourceTypeEnum);
                    });

                    JSONStorableString callbackExceptionMessage = new JSONStorableString("exceptionCallback", "", delegate (string exceptionMessage)
                    {
                        if (callbackException != null) callbackException(exceptionMessage, resourceTypeEnum);
                        else SuperController.LogError("BAInterop.GetTagNames exception callback from BA: " + exceptionMessage);
                    });

                    var objects = new object[5];
                    objects[0] = resourceTypeEnum;
                    objects[1] = tagsList;
                    objects[2] = callbackActionSuccess;
                    objects[3] = callbackActionFail;
                    objects[4] = callbackExceptionMessage;

                    BAPlugin.SendMessage("OnGetTagNames", objects);
                }
                else if (callbackFail != null)
                {
                    string failureMessage = "A request to retrieve all Tag Names from BrowswerAssist failed due to the plugin not being available.";
                    if (enableFailureLogging) SuperController.LogMessage("BAInterop.GetTagNames: " + failureMessage);
                    callbackFail(failureMessage, resourceTypeEnum);

                }
            }
            catch (Exception e)
            {
                if (callbackException != null) callbackException(e.ToString(), resourceTypeEnum);
                else SuperController.LogError("BAInterop.GetTagNames exception: " + e);
            }
        }

        public delegate void GetCreatorNamesCallback(List<string> creatorNamesList, int resourceTypeEnum);

        // 'GetCreatorNames' will obtain a list of all Creator Names for the specified Resource Type. The callback method specified will be triggered with the list of Creator names as a parameter. Alternative callbacks can optionally be specified if the function fails or triggers an exception
        public static void GetCreatorNames(int resourceTypeEnum, GetTagNamesCallback callback, CallbackFail callbackFail = null, CallbackException callbackException = null)
        {
            try
            {
                if (isBAenabled)
                {
                    var creatorsList = new List<string>();

                    JSONStorableAction callbackActionSuccess = new JSONStorableAction("successCallback", delegate
                    {
                        if (callback != null) callback(creatorsList, resourceTypeEnum);
                    });

                    JSONStorableString callbackActionFail = new JSONStorableString("failCallback", "", delegate (string failureMessage)
                    {
                        if (enableFailureLogging) SuperController.LogMessage("BAInterop.GetCreatorNames: " + failureMessage);
                        if (callbackFail != null) callbackFail(failureMessage, resourceTypeEnum);
                    });

                    JSONStorableString callbackExceptionMessage = new JSONStorableString("exceptionCallback", "", delegate (string exceptionMessage)
                    {
                        if (callbackException != null) callbackException(exceptionMessage, resourceTypeEnum);
                        else SuperController.LogError("BAInterop.GetCreatorNames exception callback from BA: " + exceptionMessage);
                    });

                    var objects = new object[5];
                    objects[0] = resourceTypeEnum;
                    objects[1] = creatorsList;
                    objects[2] = callbackActionSuccess;
                    objects[3] = callbackActionFail;
                    objects[4] = callbackExceptionMessage;

                    BAPlugin.SendMessage("OnGetCreatorNames", objects);
                }
                else if (callbackFail != null)
                {
                    string failureMessage = "A request to retrieve all Creator Names from BrowswerAssist failed due to the plugin not being available.";
                    if (enableFailureLogging) SuperController.LogMessage("BAInterop.GetCreatorNames: " + failureMessage);
                    callbackFail(failureMessage, resourceTypeEnum);

                }
            }
            catch (Exception e)
            {
                if (callbackException != null) callbackException(e.ToString(), resourceTypeEnum);
                else SuperController.LogError("BAInterop.GetCreatorNames exception: " + e);
            }
        }

        public delegate void GetSupportedResourceTypesCallback(HashSet<int> resourceTypesList);
        public delegate void GetSupportedResourceTypesallbackFail(string failureMessage);
        public delegate void GetSupportedResourceTypesCallbackException(string exceptionMessage);

        // 'GetSupportedResourceTypes' will obtain a list of all Resource Types that are supported. The callback method specified will be triggered with the list of resource type as a parameter.  Alternative callbacks can optionally be specified if the function fails or triggers an exception 
        public static void GetSupportedResourceTypes(GetSupportedResourceTypesCallback callback, GetSupportedResourceTypesallbackFail callbackFail = null, GetSupportedResourceTypesCallbackException callbackException = null)
        {
            try
            {
                if (isBAenabled)
                {
                    var resourceTypesList = new HashSet<int>();

                    JSONStorableAction callbackActionSuccess = new JSONStorableAction("successCallback", delegate
                    {
                        if (callback != null) callback(resourceTypesList);
                    });

                    JSONStorableString callbackActionFail = new JSONStorableString("failCallback", "", delegate (string failureMessage)
                    {
                        if (enableFailureLogging) SuperController.LogMessage("BAInterop.GetTagNames: " + failureMessage);
                        if (callbackFail != null) callbackFail(failureMessage);
                    });

                    JSONStorableString callbackExceptionMessage = new JSONStorableString("exceptionCallback", "", delegate (string exceptionMessage)
                    {
                        if (callbackException != null) callbackException(exceptionMessage);
                        else SuperController.LogError("BAInterop.GetSupportedResourceTypes exception callback from BA: " + exceptionMessage);
                    });

                    var objects = new object[4];
                    objects[0] = resourceTypesList;
                    objects[1] = callbackActionSuccess;
                    objects[2] = callbackActionFail;
                    objects[3] = callbackExceptionMessage;

                    BAPlugin.SendMessage("OnGetSupportedResourceTypes", objects);
                }
                else if (callbackFail != null)
                {
                    string failureMessage = "A request to retrieve all supported Resource Types from BrowswerAssist failed due to the plugin not being available.";
                    if (enableFailureLogging) SuperController.LogMessage("BAInterop.GetSupportedResourceTypes: " + failureMessage);
                    callbackFail(failureMessage);

                }
            }
            catch (Exception e)
            {
                if (callbackException != null) callbackException(e.ToString());
                else SuperController.LogError("BAInterop.GetSupportedResourceTypes exception: " + e);
            }
        }

        public delegate void GetFilteredResourceFileNamesCallbackFail(string failureMessage, BAResourceFilter filter);
        public delegate void GetFilteredResourceFileNamesCallbackException(string exceptionMessage, BAResourceFilter filter);
        public delegate void GetFilteredResourceFileNamesCallback(HashSet<string> resourceFileNames, BAResourceFilter filter);
        public static void GetFilteredResourceFilenames(BAResourceFilter filter, GetFilteredResourceFileNamesCallback callback, GetFilteredResourceFileNamesCallbackFail callbackFail = null, GetFilteredResourceFileNamesCallbackException callbackException = null)
        {
            try
            {
                if (isBAenabled)
                {
                    var resourceFileNames = new HashSet<string>();

                    JSONStorableAction callbackActionSuccess = new JSONStorableAction("successCallback", delegate
                    {
                        if (callback != null) callback(resourceFileNames, filter);
                    });


                    JSONStorableString callbackActionFail = new JSONStorableString("failCallback", "", delegate (string failureMessage)
                    {
                        if (enableFailureLogging) SuperController.LogMessage("BAInterop.GetFilteredResourceFilenames: " + failureMessage);
                        if (callbackFail != null) callbackFail(failureMessage, filter);
                    });

                    JSONStorableString callbackExceptionMessage = new JSONStorableString("exceptionCallback", "", delegate (string exceptionMessage)
                    {
                        if (callbackException != null) callbackException(exceptionMessage, filter);
                        else SuperController.LogError("BAInterop.GetFilteredResourceFilenames exception callback from BA: " + exceptionMessage);
                    });

                    var filterDict = new Dictionary<int, object>();
                    PackFilterDict(filter, filterDict);

                    var objects = new object[5];
                    objects[0] = filterDict;
                    objects[1] = resourceFileNames;
                    objects[2] = callbackActionSuccess;
                    objects[3] = callbackActionFail;
                    objects[4] = callbackExceptionMessage;

                    BAPlugin.SendMessage("OnGetFilteredResourceFilenames", objects);
                }
                else if (callbackFail != null)
                {
                    string failureMessage = "A request to retrieve a filtered list of resources from BrowswerAssist failed due to the plugin not being available.";
                    if (enableFailureLogging) SuperController.LogMessage("BAInterop.GetFilteredResourceFilenames: " + failureMessage);
                    callbackFail(failureMessage, filter);
                }
            }
            catch (Exception e)
            {
                if (callbackException != null) callbackException(e.ToString(), filter);
                else SuperController.LogError("BAInterop.GetFilteredResourceFilenames exception: " + e);
            }
        }

        public delegate void GetOrderedFilteredResourceFileNamesCallback(List<string> resourceFileNames, BAOrderedResourceFilter filter);
        public delegate void GeOrderedtFilteredResourceFileNamesCallbackFail(string failureMessage, BAOrderedResourceFilter filter);
        public delegate void GetOrderedFilteredResourceFileNamesCallbackException(string exceptionMessage, BAOrderedResourceFilter filter);
        public static void GetOrderedFilteredResourceFilenames(BAOrderedResourceFilter filter, GetOrderedFilteredResourceFileNamesCallback callback, GeOrderedtFilteredResourceFileNamesCallbackFail callbackFail = null, GetOrderedFilteredResourceFileNamesCallbackException callbackException = null)
        {
            try
            {
                if (isBAenabled)
                {
                    var resourceFileNames = new List<string>();

                    JSONStorableAction callbackActionSuccess = new JSONStorableAction("successCallback", delegate
                    {
                        if (callback != null) callback(resourceFileNames, filter);

                    });


                    JSONStorableString callbackActionFail = new JSONStorableString("failCallback", "", delegate (string failureMessage)
                    {
                        if (enableFailureLogging) SuperController.LogMessage("BAInterop.GetOrderedFilteredResourceFilenames: " + failureMessage);
                        if (callbackFail != null) callbackFail(failureMessage, filter);
                    });

                    JSONStorableString callbackExceptionMessage = new JSONStorableString("exceptionCallback", "", delegate (string exceptionMessage)
                    {
                        if (callbackException != null) callbackException(exceptionMessage, filter);
                        else SuperController.LogError("BAInterop.GetOrderedFilteredResourceFilenames exception callback from BA: " + exceptionMessage);
                    });

                    var filterDict = new Dictionary<int, object>();
                    PackFilterDict(filter, filterDict);

                    var objects = new object[5];
                    objects[0] = filterDict;
                    objects[1] = resourceFileNames;
                    objects[2] = callbackActionSuccess;
                    objects[3] = callbackActionFail;
                    objects[4] = callbackExceptionMessage;

                    BAPlugin.SendMessage("OnGetOrderedFilteredResourceFilenames", objects);
                }
                else if (callbackFail != null)
                {
                    string failureMessage = "A request to retrieve an ordered filtered list of resources from BrowswerAssist failed due to the plugin not being available.";
                    if (enableFailureLogging) SuperController.LogMessage("BAInterop.GetOrderedFilteredResourceFilenames: " + failureMessage);
                    callbackFail(failureMessage, filter);
                }
            }
            catch (Exception e)
            {
                if (callbackException != null) callbackException(e.ToString(), filter);
                else SuperController.LogError("BAInterop.GetOrderedFilteredResourceFilenames exception: " + e);
            }
        }

        private static void PackFilterDict(BAResourceFilter filter, Dictionary<int, object> filterDict)
        {
            filterDict.Add(resourceTypeKey, filter.resourceType);
            filterDict.Add(tagGroupTypeKey, filter.tagGroupType);
            if (filter.tagGroupType==BATagGroupTypeEnum.userTag) filterDict.Add(userTagNameNameKey, filter.userTagName);
            filterDict.Add(showHiddenKey, filter.showHidden);
            filterDict.Add(onlyFavKey, filter.onlyFav);
            filterDict.Add(onlyNewKey, filter.onlyNew);
            filterDict.Add(creatorTypeKey, filter.creatorType);
            if (filter.creatorType == BACreatorTypeEnum.specificCreator) filterDict.Add(creatorNameKey, filter.creatorName);
            if (filter.creatorType == BACreatorTypeEnum.localFolders)
            {
                filterDict.Add(localFolderKey, filter.localFolder);
                filterDict.Add(localFolderIncSubFolderKey, filter.includeSubFolders);
            }
            if (filter.creatorType == BACreatorTypeEnum.allPackageCreators || filter.creatorType == BACreatorTypeEnum.specificCreator) filterDict.Add(varLicenseKey, filter.varLicenseType);
            filterDict.Add(resourceNameFilterModeKey, filter.resourceNameFilterMode);
            filterDict.Add(resourceNameKey, filter.resourceName);
        }
        private static void PackFilterDict(BAOrderedResourceFilter filter, Dictionary<int, object> filterDict)
        {
            PackFilterDict(filter as BAResourceFilter, filterDict);
            filterDict.Add(orderByKey, filter.resourceOrder);
        }


        protected const int resourceTypeKey = 1;
        protected const int tagGroupTypeKey = 2;
        protected const int userTagNameNameKey = 3;
        protected const int showHiddenKey = 4;
        protected const int onlyFavKey = 5;
        protected const int onlyNewKey = 6;
        protected const int creatorTypeKey = 7;
        protected const int creatorNameKey = 8;
        protected const int localFolderKey = 9;
        protected const int localFolderIncSubFolderKey = 10;
        protected const int varLicenseKey = 11;
        protected const int resourceNameFilterModeKey = 12;
        protected const int resourceNameKey = 13;
        protected const int orderByKey = 14;
        protected const int selectModeKey = 15;
    }


    public static class BAResourceTypeEnum
    {
        public const int scene = 1;
        public const int presetAppearance = 2;
        public const int presetAnimation = 3;
        public const int presetBreastPhys = 4;
        public const int presetClothing = 5;
        public const int presetGeneral = 6;
        public const int presetGlutePhysics = 7;
        public const int presetHair = 8;
        public const int presetMorphs = 9;
        public const int presetPlugins = 10;
        public const int presetPose = 11;
        public const int presetSkin = 12;
        public const int personTexture = 13;
        public const int atomTexture = 14;
        public const int plugins = 15;
    }

    public static class BATagGroupTypeEnum
    {
        public const int userDefault = -1;
        public const int anyTags = 1;
        public const int hiddenOnly = 2;
        public const int noTags = 3;
        public const int noUserTags = 4;
        public const int userTag = 100;
    }

    public static class BAShowHiddenEnum
    {
        public const int userDefault = -1;
        public const int includeHidden = 1;
        public const int excludeHidden = 2;
    }

    public static class BAOnlyFavoriteEnum
    {
        public const int userDefault = -1;
        public const int onlyFavorites = 1;
        public const int includeNotFavorites = 2;
    }

    public static class BAOnlyNewEnum
    {
        public const int userDefault = -1;
        public const int onlyNew = 1;
        public const int includeNotNew = 2;
    }

    public static class BACreatorTypeEnum
    {
        public const int userDefault = -1;
        public const int allPackageCreators = 1;
        public const int localFolders = 2;
        public const int allLocalAndCreators = 3;
        public const int specificCreator = 4;
    }

    public static class BALicenseTypeEnum
    {
        public const int userDefault = -1;
        public const int Unknown = 0;
        public const int Any = 1;
        public const int PC = 2;
        public const int PCEA = 3;
        public const int Questionable = 4;
        public const int FC = 5;
        public const int CCBY = 6;
        public const int CCBYSA = 7;
        public const int CCBYND = 8;
        public const int CCBYNC = 9;
        public const int CCBYNCSA = 10;
        public const int CCBYNCND = 11;

    }

    public static class BAResourceNameFilterModeEnum
    {
        public const int userDefault = -1;
        public const int StartsWith = 1;
        public const int Contains = 2;
        public const int ContainsFullPath = 3;
    }

    public static class BAResultsSortModeEnum
    {
        public const int userDefault = -1;
        public const int AtoZ = 1;
        public const int ZtoA = 2;
        public const int packageFolder = 3;
        public const int newDateTime = 4;
        public const int reverseNewDateTime = 5;
        public const int updatedDateTime = 6;
        public const int reverseUpdatedDateTime = 7;
    }

    public static class BABrowserSelectModeEnum
    {
        public const int instant = 1;
        public const int single = 2;
        public const int multi = 3;
    }
}
